@@ -1,18 +1,18 @@
 package Catalyst::View::JSON;
 
 use strict;
-our $VERSION = '0.23';
+our $VERSION = '0.25';
 
 use base qw( Catalyst::View );
 use Encode ();
-use NEXT;
+use MRO::Compat;
 use Catalyst::Exception;
 
 __PACKAGE__->mk_accessors(qw( allow_callback callback_param expose_stash encoding json_dumper no_x_json_header ));
 
 sub new {
     my($class, $c, $arguments) = @_;
-    my $self = $class->NEXT::new($c);
+    my $self = $class->next::method($c);
 
     for my $field (keys %$arguments) {
         next if $field eq 'json_driver';
@@ -234,7 +234,7 @@ C<encode_json> method in your View class.
   package MyApp::View::JSON;
   use base qw( Catalyst::View::JSON );
 
-  use JSON::XS;
+  use JSON::XS ();
 
   sub encode_json {
       my($self, $c, $data) = @_;
@@ -421,4 +421,9 @@ Jun Kuriyama
 
 L<Catalyst>, L<JSON>, L<Encode::JavaScript::UCS>
 
+L<http://www.prototypejs.org/learn/json>
+L<http://docs.jquery.com/Ajax/jQuery.getJSON>
+L<http://manual.dojotoolkit.org/json.html>
+L<http://developer.yahoo.com/yui/json/>
+
 =cut
